@@ -12,8 +12,8 @@ use swc_common::{
 use swc_ecma_ast::*;
 use swc_ecma_transforms_base::helper;
 use swc_ecma_utils::{
-    find_ids, ident::IdentLike, member_expr, private_ident, quote_ident, quote_str,
-    var::VarCollector, DestructuringFinder, ExprFactory, IsDirective,
+    ident::IdentLike, member_expr, private_ident, quote_ident, quote_str, var::VarCollector,
+    DestructuringFinder, ExprFactory, IsDirective,
 };
 use swc_ecma_visit::{noop_fold_type, noop_visit_type, Fold, FoldWith, Visit, VisitWith};
 
@@ -193,19 +193,6 @@ impl Fold for CommonJs {
             }
         }
 
-        for item in &items {
-            if let ModuleItem::ModuleDecl(ModuleDecl::ExportDecl(ExportDecl {
-                decl: Decl::Var(v),
-                ..
-            })) = item
-            {
-                self.scope
-                    .borrow_mut()
-                    .exported_var_decls
-                    .extend(find_ids(&v.decls));
-            }
-        }
-
         // Make another preliminary pass to collect all import sources and their
         // specifiers.
         for item in &items {
@@ -399,9 +386,9 @@ impl Fold for CommonJs {
                             decl: Decl::Var(var),
                             ..
                         })) => {
-                            let new_var = var.clone().fold_with(self);
-
-                            extra_stmts.push(ModuleItem::Stmt(Stmt::Decl(Decl::Var(new_var))));
+                            extra_stmts.push(ModuleItem::Stmt(Stmt::Decl(Decl::Var(
+                                var.clone().fold_with(self),
+                            ))));
 
                             let mut scope = self.scope.borrow_mut();
                             var.decls.visit_with(&mut VarCollector {
@@ -633,23 +620,24 @@ impl Fold for CommonJs {
                                     }
                                 };
 
-                                let is_reexport = export.src.is_some()
-                                    || scope
-                                        .idents
-                                        .contains_key(&(orig.sym.clone(), orig.span.ctxt()));
-
                                 drop(scope);
 
                                 let old = self.in_top_level;
 
-                                // When we are in top level we make import not lazy.
-                                let is_top_level = if lazy { !is_reexport } else { true };
-                                self.in_top_level = is_top_level;
-
                                 let value = match imported {
-                                    Some(ref imported) => Box::new(
-                                        imported.clone().unwrap().make_member(orig.clone()),
-                                    ),
+                                    Some(ref imported) => {
+                                        let receiver = if lazy {
+                                            Expr::Call(CallExpr {
+                                                span: DUMMY_SP,
+                                                callee: imported.clone().unwrap().as_callee(),
+                                                args: vec![],
+                                                type_args: Default::default(),
+                                            })
+                                        } else {
+                                            Expr::Ident(imported.clone().unwrap())
+                                        };
+                                        Box::new(receiver.make_member(orig.clone()))
+                                    }
                                     None => Box::new(Expr::Ident(orig.clone()).fold_with(self)),
                                 };
 
