@@ -566,7 +566,7 @@ define(["exports"], function (_exports) {
   var test1 = 2;
   _exports.test = test1;
   _exports.test = test1 = 5;
-  _exports.test = test1 = +test1 + 1;
+  test1++, _exports.test = test1;
 
   (function () {
     var test = 2;
